;; Generated package description from marginalia.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "marginalia" "2.7.0.20260104.111923" "Enrich existing commands with completion annotations" '((emacs "29.1") (compat "30")) :commit "fc0cee1151fced42db6014e1d29a61ed63de81d9" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("docs" "help" "matching" "completion") :url "https://github.com/minad/marginalia")
